@@ -1,6 +1,6 @@
 package Hash::Storage::Driver::Memory;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use v5.10;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use File::Slurp;
 use Storable qw/dclone/;
 
-use base "Hash::Storage::Driver::Base";
+use base 'Hash::Storage::Driver::Base';
 
 sub init {
     my ($self) = @_;
